#!/bin/sh

# Build Script written for 'idesk'
# Project home page: http://sourceforge.net/projects/idesk/
# Source URL: http://sourceforge.net/project/showfiles.php?group_id=83307&package_id=85671&release_id=371735
# Build Dependencies: Standard Zenwalk 4.6 Environment
# Created By: raphael
# Maintainer E-Mail: rts417@yahoo.com
# Date of Build-Script Completion: Friday, June 22, 2007



# Package Variables.

name='idesk'
version='0.7.5'
build='48.1'



# Architecture Variables.

arch='i486'
tune='i686'



# Local Variables.

buildDir=$(pwd)
srcPkg=$buildDir/$name-$version.tar.bz2
srcDir=$buildDir/$name-$version
package=$name-$version-$arch-$build
dest=$buildDir/$package



# Clean The Work Area, Prepare New Build Area

cd $buildDir
rm -rf $dest
rm -rf $package.tgz
rm -rf $package.md5
rm -rf $package.dep
rm -rf $srcDir
tar -xvf $srcPkg
mkdir -p $dest
mkdir -p $dest/usr/src/$name-$version
mkdir -p $dest/install
mkdir -p $dest/usr/share/idesk/.idesktop



# Correct Ownerships/Permissions; Set C Flags

chown -R root:root .
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;
export CFLAGS="-O2 -march=$arch -mtune=$tune"
export CXXFLAGS="-O2 -march=$arch -mtune=$tune"



# Set ./configure Options

cd $srcDir
./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --localstatedir=/var \
  --with-x



# Build the Software

cd $srcDir
make DESTDIR=$dest
make install DESTDIR=$dest



# Strip Executables

cd $dest
chown -R root:root $dest/usr/bin
( cd $dest
   find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
   find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)



# Compress Man Page

gzip -9 $dest/usr/man/man?/*



# Modify the Initialization File
rm -f $dest/usr/share/idesk/dot.ideskrc
cat <<EOF00 >$dest/usr/share/idesk/dot.ideskrc
table Config
  FontName: arial
  FontSize: 10
  FontColor: #FFFFFF
  ToolTip.FontSize: 10
  ToolTip.FontName: arial
  ToolTip.ForeColor: #0000FF
  ToolTip.BackColor: #FFFFFF
  ToolTip.CaptionOnHover: false
  ToolTip.CaptionPlacement: Right
  CursorOver: Tcross
  Locked: false
  Transparency: 100
  Shadow: true
  ShadowColor: #000000
  ShadowX: 1
  ShadowY: 1 
  Bold: true
  ClickDelay: 250
  IconSnap: true
  SnapWidth: 10
  SnapHeight: 10
  SnapOrigin: Center
  SnapShadow: false
  SnapShadowTrans: 200
  CaptionOnHover: true
  CaptionPlacement: top
  FillStyle: fillinvert
  Background.Delay: 0
  Background.Source: None
  Background.File: None 
  Background.Mode: None
  Background.Color: None
end

table Actions
  Lock: middle singleClk
  Reload: middle doubleClk
  Drag: left hold
  EndDrag: left singleClk
  Execute[0]: left doubleClk
  Execute[1]: right doubleClk
end
EOF00



# Create Sample Icon Configuration Files

cat <<EOF00 >$dest/usr/share/idesk/.idesktop/"Audio_Player.lnk"
table Icon
  Caption: Audio Player
  Icon: /usr/share/icons/hicolor/48x48/apps/audacious.png
  Width: 48
  Height: 48
  X: 500
  Y: 500
  Command[0]: /usr/bin/audacious
  Command[1]: /usr/bin/audacious
end
EOF00

cat <<EOF00 >$dest/usr/share/idesk/.idesktop/"Email.lnk"
table Icon
  Caption: Email
  Icon: /usr/share/icons/hicolor/48x48/stock/navigation/stock_terminal-mailreader.png
  Width: 48
  Height: 48
  X: 550
  Y: 500
  Command[0]: /usr/bin/thunderbird
  Command[1]: /usr/bin/thunderbird
end
EOF00

cat <<EOF00 >$dest/usr/share/idesk/.idesktop/"File Manager.lnk"
table Icon
  Caption: File Manager
  Icon: /usr/share/icons/hicolor/16x16/apps/Thunar.png
  Width: 48
  Height: 48
  X: 600
  Y: 500
  Command[0]: /usr/bin/thunar ~/
  Command[1]: /usr/bin/thunar /
end
EOF00

cat <<EOF00 >$dest/usr/share/idesk/.idesktop/"Graphics Editor.lnk"
table Icon
  Caption: Graphics Editor
  Icon: /usr/share/icons/hicolor/48x48/apps/gimp.png
  Width: 48
  Height: 48
  X: 650
  Y: 500
  Command[0]: /usr/bin/gimp
  Command[1]: /usr/bin/gimp
end
EOF00

cat <<EOF00 >$dest/usr/share/idesk/.idesktop/"Internet Chat.lnk"
table Icon
  Caption: Internet Chat
  Icon: /usr/share/icons/hicolor/48x48/apps/pidgin.png
  Width: 48
  Height: 48
  X: 700
  Y: 500
  Command[0]: /usr/bin/pidgin
  Command[1]: /usr/bin/pidgin
end
EOF00

cat <<EOF00 >$dest/usr/share/idesk/.idesktop/"Terminal.lnk"
table Icon
  Caption: Terminal
  Icon: /usr/share/icons/hicolor/48x48/apps/Terminal.png
  Width: 48
  Height: 48
  X: 500
  Y: 550
  Command[0]: /usr/bin/xfterm4 ~/
  Command[1]: /usr/bin/xfterm4 /
end
EOF00

cat <<EOF00 >$dest/usr/share/idesk/.idesktop/"Web Browser.lnk"
table Icon
  Caption: Web Browser
  Icon: /usr/share/icons/hicolor/48x48/stock/navigation/stock_terminal-webbrowser.png
  Width: 48
  Height: 48
  X: 550
  Y: 550
  Command[0]: /usr/bin/firefox
  Command[1]: /usr/bin/firefox ~/
end
EOF00

cat <<EOF00 >$dest/usr/share/idesk/.idesktop/"Word Processor.lnk"
table Icon
  Caption: Word Processor
  Icon: /usr/share/icons/hicolor/48x48/apps/abiword.png
  Width: 48
  Height: 48
  X: 600
  Y: 550
  Command[0]: /usr/bin/abiword
  Command[1]: /usr/bin/abiword
end
EOF00

cat <<EOF00 >$dest/usr/share/idesk/.idesktop/"System Configuration.lnk"
table Icon
  Caption: System Configuration
  Icon: /usr/share/icons/hicolor/48x48/stock/navigation/stock_terminal-colors.png
  Width: 48
  Height: 48
  X: 650
  Y: 550
  Command[0]: gksu zenpanel
  Command[1]: gksu zenpanel
end
EOF00
chmod 644 $dest/usr/share/idesk/.idesktop/*



# Copy The Build Script To The Package

cp $buildDir/build-$name.sh $dest/usr/src/$name-$version/build-$name.sh



# Create The Slack Description File.

#    |-----handy-ruler------------------------------------------------------|
cat <<EOF > $dest/install/slack-desc
$name: Creates configurable desktop icons
$name:
$name: Icons are created on the desktop, allowing custom commands to be
$name: executed when an icon is clicked.  Idesk supports transparent icons,
$name: icons of a custom size, and actions for single- double- and triple-
$name: clicks
$name:
$name:
$name:
$name:
$name:
EOF



# Create The Package And Clean Up

cd $dest
makepkg -l y -c n ../$package.tgz
cd $buildDir

rm -rf $srcDir
rm -rf $dest



# Create The .dep File

requiredbuilder -z $package.tgz > $package.dep



# Generate The MD5 Checksum

md5sum $package.tgz > $package.md5